@@ -412,7 +412,8 @@ function(vcf, tumor.id.in.vcf, allowed = 0.05) {
         flog.warn("DP FORMAT field contains NAs. Removing %i variants.", n - length(vcf))
     }
     if (check.DB) {
-        if (is.null(info(vcf)[[DB.info.flag]])) {
+        if (is.null(info(vcf)[[DB.info.flag]]) ||
+            all(unlist(sapply(info(vcf)[[DB.info.flag]], is.na)))) {
             # try to add an DB field based on rownames
             vcf <- .addDbField(vcf, DB.info.flag, POPAF.info.field, min.pop.af)
         } else if (!is.null(info(vcf)[[POPAF.info.field]])) {
@@ -512,8 +513,8 @@ function(vcf, tumor.id.in.vcf, allowed = 0.05) {
         db <- grepl("^rs", rownames(vcf))
 
         if (!sum(db)) {
-           .stopUserError("vcf.file has no %s or %s info field for membership in germline databases.",
-            DB.info.flag, POPAF.info.field)
+           .stopUserError("vcf.file has no ", DB.info.flag, " or ", POPAF.info.field,
+               " info field for membership in germline databases.")
         } else {
            flog.warn("vcf.file has no %s or %s info field for membership in germline databases.%s",
                DB.info.flag, POPAF.info.field, " Guessing it based on available dbSNP ID.")
@@ -692,6 +693,9 @@ function(vcf, tumor.id.in.vcf, allowed = 0.05) {
 .filterVcfByBQ <- function(vcf, tumor.id.in.vcf, min.base.quality) {
     n.vcf.before.filter <- .countVariants(vcf)
     idx <- .getBQFromVcf(vcf, tumor.id.in.vcf, base.quality.offset = 0) < min.base.quality
+    if (sum(idx, na.rm = TRUE) / length(idx) > 0.5) {
+        flog.warn("Many variants removed by min.base.quality (%i) filter. You might want to lower the cutoff.", min.base.quality)
+    }
     vcf <- .removeVariants(vcf, idx, "BQ", na.rm = FALSE)
     flog.info("Removing %i low quality variants with non-offset BQ < %i.",
         n.vcf.before.filter - .countVariants(vcf), min.base.quality)
